==> grafana-alloy-debug-1.12.0-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/grafana/beyla/v2@v2.7.8/pkg/internal/discover/survey.go <==
package discover

import (
	"log/slog"
	"os"

	obiDiscover "go.opentelemetry.io/obi/pkg/components/discover"
	ebpfcommon "go.opentelemetry.io/obi/pkg/components/ebpf/common"
	"go.opentelemetry.io/obi/pkg/pipe/msg"
	"go.opentelemetry.io/obi/pkg/pipe/swarm"
	"go.opentelemetry.io/obi/pkg/services"

	"github.com/grafana/beyla/v2/pkg/beyla"
)

var namespaceFetcherFunc = ebpfcommon.FindNetworkNamespace
var hasHostPidAccess = ebpfcommon.HasHostPidAccess
var osPidFunc = os.Getpid

func SurveyCriteriaMatcherProvider(
	cfg *beyla.Config,
	input *msg.Queue[[]obiDiscover.Event[obiDiscover.ProcessAttrs]],
	output *msg.Queue[[]obiDiscover.Event[obiDiscover.ProcessMatch]],
) swarm.InstanceFunc {
	beylaNamespace, _ := namespaceFetcherFunc(int32(osPidFunc()))
	m := &obiDiscover.Matcher{
		Log:              slog.With("component", "obiDiscover.SurveyCriteriaMatcher"),
		Criteria:         surveyCriteria(cfg),
		ExcludeCriteria:  surveyExcludingCriteria(cfg),
		ProcessHistory:   map[obiDiscover.PID]obiDiscover.ProcessMatch{},
		Input:            input.Subscribe(msg.SubscriberName("surveyInput")),
		Output:           output,
		Namespace:        beylaNamespace,
		HasHostPidAccess: hasHostPidAccess(),
	}
	return swarm.DirectInstance(m.Run)
}

func surveyCriteria(cfg *beyla.Config) []services.Selector {
	finderCriteria := cfg.Discovery.Survey
	return obiDiscover.NormalizeGlobCriteria(finderCriteria)
}

func surveyExcludingCriteria(cfg *beyla.Config) []services.Selector {
	// deprecated options: supporting them only if the user neither defines
	// the instrument nor exclude_instrument sections
	obiCfg := cfg.AsOBI()
	if obiDiscover.OnlyDefinesDeprecatedServiceSelection(obiCfg) {
		return obiDiscover.RegexAsSelector(cfg.Discovery.DefaultExcludeServices)
	}
	return obiDiscover.GlobsAsSelector(cfg.Discovery.DefaultExcludeInstrument)
}

==> grafana-alloy-debug-1.13.0-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/grafana/beyla/v2@v2.8.5/pkg/internal/discover/survey.go <==
package discover

import (
	"log/slog"
	"os"

	obiDiscover "go.opentelemetry.io/obi/pkg/appolly/discover"
	"go.opentelemetry.io/obi/pkg/appolly/services"
	ebpfcommon "go.opentelemetry.io/obi/pkg/ebpf/common"
	"go.opentelemetry.io/obi/pkg/pipe/msg"
	"go.opentelemetry.io/obi/pkg/pipe/swarm"

	"github.com/grafana/beyla/v2/pkg/beyla"
)

var namespaceFetcherFunc = ebpfcommon.FindNetworkNamespace
var hasHostPidAccess = ebpfcommon.HasHostPidAccess
var osPidFunc = os.Getpid

func SurveyCriteriaMatcherProvider(
	cfg *beyla.Config,
	input *msg.Queue[[]obiDiscover.Event[obiDiscover.ProcessAttrs]],
	output *msg.Queue[[]obiDiscover.Event[obiDiscover.ProcessMatch]],
) swarm.InstanceFunc {
	beylaNamespace, _ := namespaceFetcherFunc(int32(osPidFunc()))
	m := &obiDiscover.Matcher{
		Log:              slog.With("component", "obiDiscover.SurveyCriteriaMatcher"),
		Criteria:         surveyCriteria(cfg),
		ExcludeCriteria:  surveyExcludingCriteria(cfg),
		ProcessHistory:   map[obiDiscover.PID]obiDiscover.ProcessMatch{},
		Input:            input.Subscribe(msg.SubscriberName("surveyInput")),
		Output:           output,
		Namespace:        beylaNamespace,
		HasHostPidAccess: hasHostPidAccess(),
	}
	return swarm.DirectInstance(m.Run)
}

func surveyCriteria(cfg *beyla.Config) []services.Selector {
	finderCriteria := cfg.Discovery.Survey
	return obiDiscover.NormalizeGlobCriteria(finderCriteria)
}

func surveyExcludingCriteria(cfg *beyla.Config) []services.Selector {
	// deprecated options: supporting them only if the user neither defines
	// the instrument nor exclude_instrument sections
	obiCfg := cfg.AsOBI()
	if obiDiscover.OnlyDefinesDeprecatedServiceSelection(obiCfg) {
		return obiDiscover.RegexAsSelector(cfg.Discovery.DefaultExcludeServices)
	}
	return obiDiscover.GlobsAsSelector(cfg.Discovery.DefaultExcludeInstrument)
}
